django\_page\_hits.tests package
================================

Submodules
----------

django\_page\_hits.tests.MockRequest module
-------------------------------------------

.. automodule:: django_page_hits.tests.MockRequest
    :members:
    :undoc-members:
    :show-inheritance:

django\_page\_hits.tests.settings module
----------------------------------------

.. automodule:: django_page_hits.tests.settings
    :members:
    :undoc-members:
    :show-inheritance:

django\_page\_hits.tests.test\_django\_page\_hits module
--------------------------------------------------------

.. automodule:: django_page_hits.tests.test_django_page_hits
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: django_page_hits.tests
    :members:
    :undoc-members:
    :show-inheritance:
